package com.engine.salary.remote.cbs8.request;

import lombok.Data;
import lombok.EqualsAndHashCode;

import java.math.BigDecimal;
import java.util.List;

@Data
@EqualsAndHashCode(callSuper = true)
public class GetDtaRequest extends CBS8BaseRequest {
    /**
     * 出票日期起    格式为yyyy-mm-dd，出票日期起止不允许一边有值一边无值，日期间隔最大为一年
     */
    private String issueDateStart;
    /**
     * 出票日期止    格式为yyyy-mm-dd，出票日期起止不允许一边有值一边无值，日期间隔最大为一年
     */
    private String issueDateEnd;
    /**
     * 到期日期起    格式为yyyy-mm-dd，到期日期起止不允许一边有值一边无值，日期间隔最大为一年
     */
    private String dueDateStart;
    /**
     * 到期日期止    格式为yyyy-mm-dd，到期日期起止不允许一边有值一边无值，日期间隔最大为一年
     */
    private String dueDateEnd;
    /**
     * 票据种类    AC01-银承，AC02-商承
     */
    private String billType;
    /**
     * 票据来源    多选。1-直联交易，2-台账交易，3-台账登记，4-挑票同步，5-任务同步
     */
    private List<String> draftSourceList;
    /**
     * 持票银行类型    多选。见附录4.1.1.银行类型枚举
     */
    private List<String> holdBankTypeList;
    /**
     * 持票人单位编码    多选。填在cbs系统公共设置>基础信息>组织机构维护的单位编码
     */
    private List<String> displayHoldOrganizationCodeList;
    /**
     * 持票人账号    多选。
     */
    private List<String> holdAccountList;
    /**
     * 持票签收日期起    格式为yyyy-mm-dd，持票签收日期起止不允许一边有值一边无值，日期间隔最大为一年
     */
    private String holdSignDateStart;
    /**
     * 持票签收日期止    格式为yyyy-mm-dd，持票签收日期起止不允许一边有值一边无值，日期间隔最大为一年
     */
    private String holdSignDateEnd;
    /**
     * 系统票据编号
     */
    private String draftNbr;
    /**
     * 票据(包)号
     */
    private String billNbr;

    /**
     * 票据金额起    大于等于0,最多为两位小数且整数位上限为13位。票据金额起止不允许一边有值一边无值。单位（元）
     */
    private BigDecimal billAmountStart;

    /**
     * 票据金额止    大于等于0,最多为两位小数且整数位上限为13位。票据金额起止不允许一边有值一边无值。单位（元）
     */
    private BigDecimal billAmountEnd;

    /**
     * 子票区间起    子票区间起止不允许一边有值一边无值，最多12位
     */
    private String subBillIntervalStart;
    /**
     * 子票区间止    子票区间起止不允许一边有值一边无值,最多12位
     */
    private String subBillIntervalEnd;
    /**
     * 系统票据类型    多选。按附录4.1.3票据类型-票据状态-流通标志级联关系表选择后按顺序填写。系统票据类型枚举见附录4.1.3。票据状态枚举见附录4.1.4。流通标志枚举见附录4.1.5。
     */
    private List<String> billVarietyList;
    /**
     * 票据状态
     */
    private List<String> billStsList;
    /**
     * 流通标志
     */
    private List<String> billTrsStsList;
    /**
     * 库存状态    1-已入库，2-已出库。 为空时默认查询全部数据
     */
    private String stockFlag;
    /**
     * 出库方式    0-空，2-背书，3-质押，4-解质，5-贴现，6-分包，7-结清, 8-作废。 为空时默认查询全部数据
     */
    private String outInvType;
    /**
     * 记录状态    NOR-正常，USE-占用，DEL-删除 SUC-完成。为空时默认查询全部数据
     */
    private String lockFlag;

}
